@@ -61,7 +61,7 @@ MyMoneyAccount::MyMoneyAccount(const QDomElement& node) :
     m_fraction(-1)
 {
   if ("ACCOUNT" != node.tagName())
-    throw new MYMONEYEXCEPTION("Node was not ACCOUNT");
+    throw MYMONEYEXCEPTION("Node was not ACCOUNT");
 
   setName(node.attribute("name"));
 
@@ -102,7 +102,7 @@ MyMoneyAccount::MyMoneyAccount(const QDomElement& node) :
   if (node.hasAttribute("openingbalance")) {
     if (!MyMoneyMoney(node.attribute("openingbalance")).isZero()) {
       QString msg = i18n("Account %1 contains an opening balance. Please use KMyMoney version 0.8 or later and earlier than version 0.9 to correct the problem.", m_name);
-      throw new MYMONEYEXCEPTION(msg);
+      throw MYMONEYEXCEPTION(msg);
     }
   }
   setDescription(node.attribute("description"));
@@ -128,6 +128,16 @@ MyMoneyAccount::MyMoneyAccount(const QDomElement& node) :
       m_onlineBankingSettings.setValue(it_attr.name(), it_attr.value());
     }
   }
+
+  // Up to and including version 4.6.6 the new account dialog stored the iban in the kvp-key "IBAN".
+  // But the rest of the software uses "iban". So correct this:
+  if (!value("IBAN").isEmpty()) {
+    // If "iban" was not set, set it now. If it is set, the user reseted it already, so remove
+    // the garbage.
+    if (value("iban").isEmpty())
+      setValue("iban", value("IBAN"));
+    deletePair("IBAN");
+  }
 }
 
 void MyMoneyAccount::setName(const QString& name)
@@ -200,29 +210,6 @@ void MyMoneyAccount::removeAccountId(const QString& account)
     m_accountList.removeAt(pos);
 }
 
-MyMoneyAccount::accountTypeE MyMoneyAccount::accountGroup(MyMoneyAccount::accountTypeE type)
-{
-  switch (type) {
-    case MyMoneyAccount::Checkings:
-    case MyMoneyAccount::Savings:
-    case MyMoneyAccount::Cash:
-    case MyMoneyAccount::Currency:
-    case MyMoneyAccount::Investment:
-    case MyMoneyAccount::MoneyMarket:
-    case MyMoneyAccount::CertificateDep:
-    case MyMoneyAccount::AssetLoan:
-    case MyMoneyAccount::Stock:
-      return MyMoneyAccount::Asset;
-
-    case MyMoneyAccount::CreditCard:
-    case MyMoneyAccount::Loan:
-      return MyMoneyAccount::Liability;
-
-    default:
-      return type;
-  }
-}
-
 bool MyMoneyAccount::operator == (const MyMoneyAccount& right) const
 {
   return (MyMoneyKeyValueContainer::operator==(right) &&
@@ -240,9 +227,27 @@ bool MyMoneyAccount::operator == (const MyMoneyAccount& right) const
           (m_institution == right.m_institution));
 }
 
-MyMoneyAccount::accountTypeE MyMoneyAccount::accountGroup(void) const
+MyMoneyAccount::accountTypeE MyMoneyAccount::accountGroup() const
 {
-  return accountGroup(m_accountType);
+  switch (m_accountType) {
+    case MyMoneyAccount::Checkings:
+    case MyMoneyAccount::Savings:
+    case MyMoneyAccount::Cash:
+    case MyMoneyAccount::Currency:
+    case MyMoneyAccount::Investment:
+    case MyMoneyAccount::MoneyMarket:
+    case MyMoneyAccount::CertificateDep:
+    case MyMoneyAccount::AssetLoan:
+    case MyMoneyAccount::Stock:
+      return MyMoneyAccount::Asset;
+
+    case MyMoneyAccount::CreditCard:
+    case MyMoneyAccount::Loan:
+      return MyMoneyAccount::Liability;
+
+    default:
+      return m_accountType;
+  }
 }
 
 void MyMoneyAccount::setCurrencyId(const QString& id)
@@ -622,36 +627,39 @@ QPixmap MyMoneyAccount::accountPixmap(bool reconcileFlag, int size) const
   switch (accountType()) {
     default:
       if (accountGroup() == MyMoneyAccount::Asset)
-        icon = "account-types-asset";
+        icon = "view-bank-account";
       else
-        icon = "account-types-liability";
+        icon = "view-loan";
       break;
 
     case MyMoneyAccount::Investment:
     case MyMoneyAccount::Stock:
     case MyMoneyAccount::MoneyMarket:
     case MyMoneyAccount::CertificateDep:
-      icon = "account-types-investments";
+      icon = "view-stock-account";
       break;
 
     case MyMoneyAccount::Checkings:
-      icon = "account-types-checking";
+      icon = "view-bank-account-checking";
       break;
     case MyMoneyAccount::Savings:
-      icon = "account-types-savings";
+      icon = "view-bank-account-savings";
       break;
 
     case MyMoneyAccount::AssetLoan:
+      icon = "view-loan-asset";
+      break;
+
     case MyMoneyAccount::Loan:
-      icon = "account-types-loan";
+      icon = "view-loan";
       break;
 
     case MyMoneyAccount::CreditCard:
-      icon = "account-types-credit-card";
+      icon = "view-credit-card-account";
       break;
 
     case MyMoneyAccount::Asset:
-      icon = "account-types-asset";
+      icon = "view-bank-account";
       break;
 
     case MyMoneyAccount::Cash:
@@ -659,15 +667,15 @@ QPixmap MyMoneyAccount::accountPixmap(bool reconcileFlag, int size) const
       break;
 
     case MyMoneyAccount::Income:
-      icon = "account-types-income";
+      icon = "view-income-categories";
       break;
 
     case MyMoneyAccount::Expense:
-      icon = "account-types-expense";
+      icon = "view-expenses-categories";
       break;
 
     case MyMoneyAccount::Equity:
-      icon = "account";
+      icon = "view-bank-account";
       break;
   }
 
@@ -680,14 +688,14 @@ QPixmap MyMoneyAccount::accountPixmap(bool reconcileFlag, int size) const
 
   QPainter pixmapPainter(&result);
   if (isClosed()) {
-    QPixmap ovly = DesktopIcon("account-types-closed", size);
-    pixmapPainter.drawPixmap(0, 0, ovly.width(), ovly.height(), ovly);
+    QPixmap ovly = DesktopIcon("dialog-close", size);
+    pixmapPainter.drawPixmap(ovly.width() / 2, ovly.height() / 2, ovly.width() / 2, ovly.height() / 2, ovly);
   } else if (reconcileFlag) {
-    QPixmap ovly = DesktopIcon("account-types-reconciled.png", size);
-    pixmapPainter.drawPixmap(0, 0, ovly.width(), ovly.height(), ovly);
+    QPixmap ovly = DesktopIcon("flag-green", size);
+    pixmapPainter.drawPixmap(size / 2, size / 2, ovly.width() / 2, ovly.height() / 2, ovly);
   } else if (!onlineBankingSettings().value("provider").isEmpty()) {
-    QPixmap ovly = DesktopIcon("online-banking.png", size);
-    pixmapPainter.drawPixmap(0, 0, ovly.width(), ovly.height(), ovly);
+    QPixmap ovly = DesktopIcon("download", size);
+    pixmapPainter.drawPixmap(size / 2, size / 2, ovly.width() / 2, ovly.height() / 2, ovly);
   }
   return result;
 }
