@@ -17,10 +17,6 @@
 #ifndef MYMONEYACCOUNT_H
 #define MYMONEYACCOUNT_H
 
-#ifdef HAVE_CONFIG_H
-#include <config-kmymoney.h>
-#endif
-
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -38,6 +34,7 @@
 #include <mymoneykeyvaluecontainer.h>
 #include <mymoneysecurity.h>
 #include <kmm_mymoney_export.h>
+#include <mymoneyunittestable.h>
 #include "mymoneyutils.h"
 class MyMoneyTransaction;
 class MyMoneyInstitution;
@@ -174,12 +171,9 @@ public:
     * - Expense
     *   - Expense
     *
-    * @param type actual account type
     * @return accountTypeE of major account type
     */
-  static MyMoneyAccount::accountTypeE accountGroup(MyMoneyAccount::accountTypeE type);
-
-  MyMoneyAccount::accountTypeE accountGroup(void) const;
+  MyMoneyAccount::accountTypeE accountGroup() const;
 
   /**
     * This method returns the id of the MyMoneyInstitution object this account
@@ -503,7 +497,7 @@ public:
     *
     * @deprecated use isIncomeExpense() instead
     */
-  bool isCategory(void) const __attribute__((deprecated));
+  KMM_MYMONEY_DEPRECATED bool isCategory(void) const;
 
   /**
     * This method returns @a true if the account type is
