@@ -114,8 +114,8 @@ public:
   void           clearSelectedFlags();
 
   /**
-  * This method is called when the user clicks 'Clear selections', in order to
-  * clear incorrect column number entries.
+  * This method is called when the user clicks 'Clear', in order to
+  * clear incorrect column number entries.  Also called on initialisation.
   */
   void           clearColumnNumbers();
 
@@ -138,11 +138,15 @@ public:
   void           setInFileName(const QString& val);
 
   /**
-  * This method ensures the rows and columns are correctly aligned
-  * when a diffent set of lines is displayed, as, among other things,
-  * the horizontal scroll-bar needs to be taken into account.
+   * Recalculates column widths for the visible rows
   */
-  void           redrawWindow(int startLine);
+  void           updateColumnWidths(int firstLine, int lastLine);
+  
+  /**
+  * Called on reading a file in order to
+  * adjust window size to suit the file.
+  */
+  void           setWindowSize(int firstLine, int lastLine);
 
   QString        columnType(int column);
   QString        invPath();
@@ -199,6 +203,7 @@ public:
   int            m_startLine;
   int            m_topLine;
   int            m_row;
+  int            m_rowWidth;
   int            m_fieldDelimiterIndex;
 
   bool           m_screenUpdated;
@@ -464,7 +469,8 @@ private:
   int            m_typeColumn;
   int            m_symbolRow;
   int            m_maxRowWidth;
-  int            m_rowWidth;
+  int            m_initWindow;
+  int            m_screenWidth;
 
   QString        m_accountName;
   QString        m_brokerBuff;
