@@ -215,6 +215,7 @@ void ListTable::render(QString& result, QString& csv) const
   i18nHeaders["value"] = i18n("Amount");
   i18nHeaders["number"] = i18n("Num");
   i18nHeaders["payee"] = i18n("Payee");
+  i18nHeaders["tag"] = i18n("Tags");
   i18nHeaders["category"] = i18n("Category");
   i18nHeaders["account"] = i18n("Account");
   i18nHeaders["memo"] = i18n("Memo");
@@ -436,6 +437,7 @@ void ListTable::render(QString& result, QString& csv) const
         else if (*it_column == "postdate"
                  || *it_column == "number"
                  || *it_column == "payee"
+                 || *it_column == "tag"
                  || *it_column == "action"
                  || *it_column == "shares"
                  || *it_column == "price"
@@ -590,12 +592,15 @@ void ListTable::render(QString& result, QString& csv) const
     QString grandtotal_html = grandtotal.formatMoney(fraction);
     QString grandtotal_csv = grandtotal.formatMoney(fraction, false);
 
-    result += "<tr class=\"sectionfooter\">"
-              "<td class=\"left0\" "
-              "colspan=\"" + QString::number(columns.count() - 1 - postcolumns.count()) + "\">" +
-              i18n("Grand Total") + "</td>"
-              "<td>" + grandtotal_html + "</td></tr>\n";
-    csv += "\"" + i18n("Grand Total") + "\",\"" + grandtotal_csv + "\"\n";
+    //If we order by Tags don't show the Grand total as we can have multiple tags per transaction
+    if (m_config.rowType() != MyMoneyReport::eTag) {
+      result += "<tr class=\"sectionfooter\">"
+                "<td class=\"left0\" "
+                "colspan=\"" + QString::number(columns.count() - 1 - postcolumns.count()) + "\">" +
+                i18n("Grand Total") + "</td>"
+                "<td>" + grandtotal_html + "</td></tr>\n";
+      csv += "\"" + i18n("Grand Total") + "\",\"" + grandtotal_csv + "\"\n";
+    }
   }
   result += "</table>\n";
 }
@@ -630,23 +635,86 @@ void ListTable::includeInvestmentSubAccounts()
 {
   // if we're not in expert mode, we need to make sure
   // that all stock accounts for the selected investment
-  // account are also selected
-  QStringList accountList;
-  if (m_config.accounts(accountList)) {
-    if (!KMyMoneyGlobalSettings::expertMode()) {
-      QStringList::const_iterator it_a, it_b;
-      for (it_a = accountList.constBegin(); it_a != accountList.constEnd(); ++it_a) {
-        MyMoneyAccount acc = MyMoneyFile::instance()->account(*it_a);
-        if (acc.accountType() == MyMoneyAccount::Investment) {
-          for (it_b = acc.accountList().constBegin(); it_b != acc.accountList().constEnd(); ++it_b) {
-            if (!accountList.contains(*it_b)) {
-              m_config.addAccount(*it_b);
-            }
-          }
+  // account are also selected.
+  // In case we get called for a non investment only report we quit
+  if (KMyMoneyGlobalSettings::expertMode() || !m_config.isInvestmentsOnly()) {
+    return;
+  }
+
+  // get all investment subAccountsList but do not include those with zero balance
+  // or those which had no transactions during the timeframe of the report
+  QStringList accountIdList;
+  QStringList subAccountsList;
+  MyMoneyFile* file = MyMoneyFile::instance();
+
+  // get the report account filter
+  if (!m_config.accounts(accountIdList)
+      && m_config.isInvestmentsOnly()) {
+    // this will only execute if this is an investment-only report
+    QList<MyMoneyAccount> accountList;
+    file->accountList(accountList);
+    QList<MyMoneyAccount>::const_iterator it_ma;
+    for (it_ma = accountList.constBegin(); it_ma != accountList.constEnd(); ++it_ma) {
+      if ((*it_ma).accountType() == MyMoneyAccount::Investment) {
+        accountIdList.append((*it_ma).id());
+      }
+    }
+  }
+
+  QStringList::const_iterator it_a;
+  for (it_a = accountIdList.constBegin(); it_a != accountIdList.constEnd(); ++it_a) {
+    MyMoneyAccount acc = file->account(*it_a);
+    if (acc.accountType() == MyMoneyAccount::Investment) {
+      QStringList::const_iterator it_b;
+      for (it_b = acc.accountList().constBegin(); it_b != acc.accountList().constEnd(); ++it_b) {
+        if (!accountIdList.contains(*it_b)) {
+          subAccountsList.append(*it_b);
         }
       }
     }
   }
+
+  if (m_config.isInvestmentsOnly()
+      && !m_config.isIncludingUnusedAccounts()) {
+    // if the balance is not zero at the end, include the subaccount
+    QStringList::iterator it_balance;
+    for (it_balance = subAccountsList.begin(); it_balance != subAccountsList.end();) {
+      if (!file->balance((*it_balance), m_config.toDate()).isZero()) {
+        m_config.addAccount((*it_balance));
+        it_balance = subAccountsList.erase((it_balance));
+
+      } else {
+        ++it_balance;
+      }
+    }
+
+    // if there are transactions for that subaccount, include them
+    MyMoneyTransactionFilter filter;
+    filter.setDateFilter(m_config.fromDate(), m_config.toDate());
+    filter.addAccount(subAccountsList);
+    filter.setReportAllSplits(false);
+
+    QList<MyMoneyTransaction> transactions = file->transactionList(filter);
+    QList<MyMoneyTransaction>::const_iterator it_t = transactions.constBegin();
+
+    //Check each split for a matching account
+    for (; it_t != transactions.constEnd(); ++it_t) {
+      const QList<MyMoneySplit>& splits = (*it_t).splits();
+      QList<MyMoneySplit>::const_iterator it_s = splits.begin();
+      for (; it_s != splits.end(); ++it_s) {
+        const QString& accountId = (*it_s).accountId();
+        if (!(*it_s).shares().isZero()
+            && subAccountsList.contains(accountId)) {
+          subAccountsList.removeOne(accountId);
+          m_config.addAccount(accountId);
+        }
+      }
+    }
+  } else {
+    // if not an investment-only report or explicitly including unused accounts
+    // add all investment subaccounts
+    m_config.addAccount(subAccountsList);
+  }
 }
 
 }
