@@ -34,6 +34,7 @@
 #include <QVBoxLayout>
 #include <QHeaderView>
 #include <QApplication>
+#include <QToolTip>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -70,6 +71,37 @@ class KGlobalLedgerView::Private
 public:
   Private();
 
+  // used to store the id of an item and the id of an immeadiate unselected sibling
+  void storeId(KMyMoneyRegister::RegisterItem *item, QString &id, QString &backupId) {
+    if (item) {
+      // the id of the item
+      id = item->id();
+      // the id of the item's previous/next unselected item
+      for (KMyMoneyRegister::RegisterItem *it = item->prevItem(); it != 0 && backupId.isEmpty(); it = it->prevItem()) {
+        if (!it->isSelected()) {
+          backupId = it->id();
+        }
+      }
+      // if we didn't found previous unselected items search trough the next items
+      for (KMyMoneyRegister::RegisterItem *it = item->nextItem(); it != 0 && backupId.isEmpty(); it = it->nextItem()) {
+        if (!it->isSelected()) {
+          backupId = it->id();
+        }
+      }
+    }
+  }
+
+  // use to match an item by it's id or a backup id which has a lower precedence
+  void matchItemById(KMyMoneyRegister::RegisterItem **item, KMyMoneyRegister::Transaction* t, QString &id, QString &backupId) {
+    if (!backupId.isEmpty() && t->id() == backupId)
+      *item = t;
+    if (!id.isEmpty() && t->id() == id) {
+      // we found the real thing there's no need for the backup anymore
+      backupId.clear();
+      *item = t;
+    }
+  }
+
   MousePressFilter*    m_mousePressFilter;
   KMyMoneyRegister::RegisterSearchLineWidget* m_registerSearchLine;
   QString              m_reconciliationAccount;
@@ -277,6 +309,8 @@ KGlobalLedgerView::KGlobalLedgerView(QWidget *parent, const char *name)
   d->m_mousePressFilter->addWidget(m_buttonFrame);
   d->m_mousePressFilter->addWidget(m_summaryFrame);
   d->m_mousePressFilter->addWidget(m_registerFrame);
+
+  m_tooltipPosn = QPoint();
 }
 
 KGlobalLedgerView::~KGlobalLedgerView()
@@ -350,7 +384,9 @@ void KGlobalLedgerView::loadView(void)
 
   QMap<QString, bool> isSelected;
   QString focusItemId;
+  QString backUpFocusItemId;  // in case the focus item is removed
   QString anchorItemId;
+  QString backUpAnchorItemId; // in case the anchor item is removed
 
   if (!m_newAccountLoaded) {
     // remember the current selected transactions
@@ -361,11 +397,9 @@ void KGlobalLedgerView::loadView(void)
       }
     }
     // remember the item that has the focus
-    if (m_register->focusItem())
-      focusItemId = m_register->focusItem()->id();
+    d->storeId(m_register->focusItem(), focusItemId, backUpFocusItemId);
     // and the one that has the selection anchor
-    if (m_register->anchorItem())
-      anchorItemId = m_register->anchorItem()->id();
+    d->storeId(m_register->anchorItem(), anchorItemId, backUpAnchorItemId);
   } else {
     d->m_registerSearchLine->searchLine()->reset();
   }
@@ -613,10 +647,8 @@ void KGlobalLedgerView::loadView(void)
         if (isSelected.contains(t->id()))
           t->setSelected(true);
 
-        if (t->id() == focusItemId)
-          focusItem = t;
-        if (t->id() == anchorItemId)
-          anchorItem = t;
+        d->matchItemById(&focusItem, t, focusItemId, backUpFocusItemId);
+        d->matchItemById(&anchorItem, t, anchorItemId, backUpAnchorItemId);
 
         const MyMoneySplit& split = t->split();
         MyMoneyMoney balance = futureBalance[split.accountId()];
@@ -630,15 +662,6 @@ void KGlobalLedgerView::loadView(void)
         }
 
         if (!t->isScheduled()) {
-          if (split.reconcileFlag() == MyMoneySplit::NotReconciled) {
-            tracer.printf("Reducing cleared balance by %s because %s/%s(%s) is not reconciled", qPrintable((split.shares() * factor).formatMoney("", 2)), qPrintable(t->transaction().id()), qPrintable(split.id()), qPrintable(t->transaction().postDate().toString(Qt::ISODate)));
-            clearedBalance[split.accountId()] -= split.shares() * factor;
-          }
-          if (isReconciliationAccount() && t->transaction().postDate() > reconciliationDate && split.reconcileFlag() == MyMoneySplit::Cleared) {
-            tracer.printf("Reducing cleared balance by %s because we are in reconciliation, %s/%s(%s)'s date is after or on reconciliation date (%s) and is cleared", qPrintable((split.shares() * factor).formatMoney("", 2)), qPrintable(t->transaction().id()), qPrintable(split.id()), qPrintable(t->transaction().postDate().toString(Qt::ISODate)), qPrintable(reconciliationDate.toString(Qt::ISODate)));
-
-            clearedBalance[split.accountId()] -= split.shares() * factor;
-          }
           if (isReconciliationAccount() && t->transaction().postDate() <= reconciliationDate && split.reconcileFlag() == MyMoneySplit::Cleared) {
             if (split.shares().isNegative()) {
               payments[split.accountId()]++;
@@ -659,6 +682,8 @@ void KGlobalLedgerView::loadView(void)
       p = p->prevItem();
     }
 
+    clearedBalance[m_account.id()] = MyMoneyFile::instance()->clearedBalance(m_account.id(), reconciliationDate);
+
     tracer.printf("total balance of %s = %s", qPrintable(m_account.name()), qPrintable(actBalance[m_account.id()].formatMoney("", 2)));
     tracer.printf("future balance of %s = %s", qPrintable(m_account.name()), qPrintable(futureBalance[m_account.id()].formatMoney("", 2)));
     tracer.printf("cleared balance of %s = %s", qPrintable(m_account.name()), qPrintable(clearedBalance[m_account.id()].formatMoney("", 2)));
@@ -695,7 +720,7 @@ void KGlobalLedgerView::loadView(void)
     if (focusItem) {
       // in case we have some selected items we just set the focus item
       // in other cases, we make the focusitem also the selected item
-      if (isSelected.count() > 1) {
+      if (anchorItem && (anchorItem != focusItem)) {
         m_register->setFocusItem(focusItem);
         m_register->setAnchorItem(anchorItem);
       } else
@@ -711,8 +736,7 @@ void KGlobalLedgerView::loadView(void)
     updateSummaryLine(actBalance, clearedBalance);
     kmymoney->slotStatusProgressBar(-1, -1);
 
-  } catch (MyMoneyException *e) {
-    delete e;
+  } catch (const MyMoneyException &) {
     m_account = MyMoneyAccount();
     clear();
   }
@@ -842,8 +866,7 @@ void KGlobalLedgerView::loadAccounts(void)
   if (!m_account.id().isEmpty()) {
     try {
       m_account = file->account(m_account.id());
-    } catch (MyMoneyException *e) {
-      delete e;
+    } catch (const MyMoneyException &) {
       m_account = MyMoneyAccount();
       return;
     }
@@ -863,7 +886,7 @@ void KGlobalLedgerView::loadAccounts(void)
                            1,
                            Qt::MatchFlags(Qt::MatchExactly | Qt::MatchCaseSensitive | Qt::MatchRecursive));
     if (list.count() > 0) {
-      QVariant accountId = Models::instance()->accountsModel()->data(list.front(), AccountsModel::AccountIdRole);
+      QVariant accountId = list.front().data(AccountsModel::AccountIdRole);
       if (accountId.isValid()) {
         m_account = file->account(accountId.toString());
       }
@@ -879,7 +902,7 @@ void KGlobalLedgerView::loadAccounts(void)
       for (QModelIndexList::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it) {
         if (!it->parent().isValid())
           continue; // skip the top level accounts
-        QVariant accountId = Models::instance()->accountsModel()->data(*it, AccountsModel::AccountIdRole);
+        QVariant accountId = (*it).data(AccountsModel::AccountIdRole);
         if (accountId.isValid()) {
           MyMoneyAccount a = file->account(accountId.toString());
           if (!a.isInvest()) {
@@ -895,9 +918,8 @@ void KGlobalLedgerView::loadAccounts(void)
     d->m_accountComboBox->setSelected(m_account.id());
     try {
       d->m_precision = MyMoneyMoney::denomToPrec(m_account.fraction());
-    } catch (MyMoneyException *e) {
+    } catch (const MyMoneyException &) {
       qDebug("Security %s for account %s not found", qPrintable(m_account.currencyId()), qPrintable(m_account.name()));
-      delete e;
       d->m_precision = 2;
     }
   }
@@ -1007,9 +1029,8 @@ bool KGlobalLedgerView::slotSelectAccount(const QString& id, const QString& tran
         }
         m_newAccountLoaded = true;
         slotLoadView();
-      } catch (MyMoneyException* e) {
+      } catch (const MyMoneyException &) {
         qDebug("Unable to retrieve account %s", qPrintable(id));
-        delete e;
         rc = false;
       }
     } else {
@@ -1038,8 +1059,10 @@ void KGlobalLedgerView::slotNewTransaction(void)
 void KGlobalLedgerView::setupDefaultAction(void)
 {
   switch (m_account.accountType()) {
-      // TODO if we want a different action for different account types
-      //      we can add cases here
+    case MyMoneyAccount::Asset:
+    case MyMoneyAccount::AssetLoan:
+    case MyMoneyAccount::Savings:
+      d->m_action = KMyMoneyRegister::ActionDeposit;
     default:
       d->m_action = KMyMoneyRegister::ActionWithdrawal;
       break;
@@ -1183,6 +1206,7 @@ TransactionEditor* KGlobalLedgerView::startEdit(const KMyMoneyRegister::Selected
 
       connect(editor, SIGNAL(objectCreation(bool)), d->m_mousePressFilter, SLOT(setFilterDeactive(bool)));
       connect(editor, SIGNAL(createPayee(QString,QString&)), kmymoney, SLOT(slotPayeeNew(QString,QString&)));
+      connect(editor, SIGNAL(createTag(QString,QString&)), kmymoney, SLOT(slotTagNew(QString,QString&)));
       connect(editor, SIGNAL(createCategory(MyMoneyAccount&,MyMoneyAccount)), kmymoney, SLOT(slotCategoryNew(MyMoneyAccount&,MyMoneyAccount)));
       connect(editor, SIGNAL(createSecurity(MyMoneyAccount&,MyMoneyAccount)), kmymoney, SLOT(slotInvestmentNew(MyMoneyAccount&,MyMoneyAccount)));
       connect(editor, SIGNAL(assignNumber()), kmymoney, SLOT(slotTransactionAssignNumber()));
@@ -1327,6 +1351,8 @@ void KGlobalLedgerView::showEvent(QShowEvent* event)
 bool KGlobalLedgerView::eventFilter(QObject* o, QEvent* e)
 {
   bool rc = false;
+  //  Need to capture mouse position here as QEvent::ToolTip is too slow
+  m_tooltipPosn = QCursor::pos();
 
   if (e->type() == QEvent::KeyPress) {
     if (m_inEditMode) {
@@ -1345,9 +1371,14 @@ bool KGlobalLedgerView::eventFilter(QObject* o, QEvent* e)
   return rc;
 }
 
+void KGlobalLedgerView::showTooltip(const QString msg) const
+{
+  QToolTip::showText(m_tooltipPosn, msg);
+}
+
 void KGlobalLedgerView::slotSortOptions(void)
 {
-  KSortOptionDlg* dlg = new KSortOptionDlg(this);
+  QPointer<KSortOptionDlg> dlg = new KSortOptionDlg(this);
 
   QString key;
   QString sortOrder, def;
@@ -1368,20 +1399,21 @@ void KGlobalLedgerView::slotSortOptions(void)
   dlg->setSortOption(sortOrder, def);
 
   if (dlg->exec() == QDialog::Accepted) {
-    sortOrder = dlg->sortOption();
-    if (sortOrder != oldOrder) {
-      if (sortOrder.isEmpty()) {
-        m_account.deletePair(key);
-      } else {
-        m_account.setValue(key, sortOrder);
-      }
-      MyMoneyFileTransaction ft;
-      try {
-        MyMoneyFile::instance()->modifyAccount(m_account);
-        ft.commit();
-      } catch (MyMoneyException* e) {
-        qDebug("Unable to update sort order for account '%s': %s", qPrintable(m_account.name()), qPrintable(e->what()));
-        delete e;
+    if (dlg != 0) {
+      sortOrder = dlg->sortOption();
+      if (sortOrder != oldOrder) {
+        if (sortOrder.isEmpty()) {
+          m_account.deletePair(key);
+        } else {
+          m_account.setValue(key, sortOrder);
+        }
+        MyMoneyFileTransaction ft;
+        try {
+          MyMoneyFile::instance()->modifyAccount(m_account);
+          ft.commit();
+        } catch (const MyMoneyException &e) {
+          qDebug("Unable to update sort order for account '%s': %s", qPrintable(m_account.name()), qPrintable(e.what()));
+        }
       }
     }
   }
@@ -1410,10 +1442,12 @@ bool KGlobalLedgerView::canCreateTransactions(QString& tooltip) const
   if (m_account.accountGroup() == MyMoneyAccount::Income
       || m_account.accountGroup() == MyMoneyAccount::Expense) {
     tooltip = i18n("Cannot create transactions in the context of a category.");
+    showTooltip(tooltip);
     rc = false;
   }
   if (m_account.isClosed()) {
     tooltip = i18n("Cannot create transactions in a closed account.");
+    showTooltip(tooltip);
     rc = false;
   }
   return rc;
@@ -1421,13 +1455,36 @@ bool KGlobalLedgerView::canCreateTransactions(QString& tooltip) const
 
 bool KGlobalLedgerView::canProcessTransactions(const KMyMoneyRegister::SelectedTransactions& list, QString& tooltip) const
 {
+  MyMoneyAccount acc;
+  QString closedAccount;
   if (m_register->focusItem() == 0)
     return false;
 
-  if (!m_register->focusItem()->isSelected()) {
-    tooltip = i18n("Cannot process transaction with focus if it is not selected.");
+  bool rc = true;
+  if (list.warnLevel() == 3) {  //Closed account somewhere
+    KMyMoneyRegister::SelectedTransactions::const_iterator it_t;
+    for (it_t = list.begin(); rc && it_t != list.end(); ++it_t) {
+      QList<MyMoneySplit> splitList = (*it_t).transaction().splits();
+      QString id = splitList.first().accountId();
+      acc = MyMoneyFile::instance()->account(id);
+      if (!acc.isClosed()) {  //wrong split, try other
+        id = splitList.last().accountId();
+        acc = MyMoneyFile::instance()->account(id);
+      }
+      closedAccount = acc.name();
+      break;
+    }
+    tooltip = i18n("Cannot process transactions in account %1, which is closed.", closedAccount);
+    showTooltip(tooltip);
     return false;
   }
+
+  if (!m_register->focusItem()->isSelected()) {
+    tooltip = i18n("Cannot process transaction with focus if it is not selected.");
+    showTooltip(tooltip);
+    return false;
+  }
+  tooltip.clear();
   return !list.isEmpty();
 }
 
@@ -1456,10 +1513,10 @@ bool KGlobalLedgerView::canEditTransactions(const KMyMoneyRegister::SelectedTran
   // check for c)
   if (list.warnLevel() == 2) {
     tooltip = i18n("Cannot edit transactions with frozen splits.");
+    showTooltip(tooltip);
     return false;
   }
 
-
   bool rc = true;
   int investmentTransactions = 0;
   int normalTransactions = 0;
@@ -1467,10 +1524,18 @@ bool KGlobalLedgerView::canEditTransactions(const KMyMoneyRegister::SelectedTran
   if (m_account.accountGroup() == MyMoneyAccount::Income
       || m_account.accountGroup() == MyMoneyAccount::Expense) {
     tooltip = i18n("Cannot edit transactions in the context of a category.");
+    showTooltip(tooltip);
+    rc = false;
+  }
+
+  if (m_account.isClosed()) {
+    tooltip = i18n("Cannot create or edit any transactions in Account %1 as it is closed", m_account.name());
+    showTooltip(tooltip);
     rc = false;
   }
 
   KMyMoneyRegister::SelectedTransactions::const_iterator it_t;
+  QString action;
   for (it_t = list.begin(); rc && it_t != list.end(); ++it_t) {
     if ((*it_t).transaction().id().isEmpty()) {
       tooltip.clear();
@@ -1478,6 +1543,21 @@ bool KGlobalLedgerView::canEditTransactions(const KMyMoneyRegister::SelectedTran
       continue;
     }
 
+    if (KMyMoneyUtils::transactionType((*it_t).transaction()) == KMyMoneyUtils::InvestmentTransaction) {
+      if (action.isEmpty()) {
+        action = (*it_t).split().action();
+        continue;
+      }
+      if (action == (*it_t).split().action()) {
+        continue;
+      } else {
+        tooltip = (i18n("Cannot edit mixed investment action/type transactions together."));
+        showTooltip(tooltip);
+        rc = false;
+        break;
+      }
+    }
+
     if (KMyMoneyUtils::transactionType((*it_t).transaction()) == KMyMoneyUtils::InvestmentTransaction)
       ++investmentTransactions;
     else
@@ -1486,6 +1566,7 @@ bool KGlobalLedgerView::canEditTransactions(const KMyMoneyRegister::SelectedTran
     // check for a)
     if (investmentTransactions != 0 && normalTransactions != 0) {
       tooltip = i18n("Cannot edit investment transactions and non-investment transactions together.");
+      showTooltip(tooltip);
       rc = false;
       break;
     }
@@ -1494,6 +1575,7 @@ bool KGlobalLedgerView::canEditTransactions(const KMyMoneyRegister::SelectedTran
     if ((*it_t).transaction().splitCount() > 2 && normalTransactions != 0) {
       if (list.count() > 1) {
         tooltip = i18n("Cannot edit multiple split transactions at once.");
+        showTooltip(tooltip);
         rc = false;
         break;
       }
@@ -1503,10 +1585,12 @@ bool KGlobalLedgerView::canEditTransactions(const KMyMoneyRegister::SelectedTran
   // check for multiple transactions being selected in an investment account
   // we do not allow editing in this case: https://bugs.kde.org/show_bug.cgi?id=240816
   // later on, we might allow to edit investment transactions of the same type
-  if (rc == true && investmentTransactions > 1) {
-    tooltip = i18n("Cannot edit multiple investment transactions at once");
-    rc = false;
-  }
+  ///  Can now disable the following check.
+
+  /*  if (rc == true && investmentTransactions > 1) {
+      tooltip = i18n("Cannot edit multiple investment transactions at once");
+      rc = false;
+    }*/
 
   // now check that we have the correct account type for investment transactions
   if (rc == true && investmentTransactions != 0) {
@@ -1517,5 +1601,3 @@ bool KGlobalLedgerView::canEditTransactions(const KMyMoneyRegister::SelectedTran
   }
   return rc;
 }
-
-#include "kgloballedgerview.moc"
