@@ -46,6 +46,28 @@
 #include "kmymoney.h"
 #include "models.h"
 
+/**
+  * This class is only needed to implement proper sorting.
+  */
+class InvestmentItem : public QTreeWidgetItem
+{
+public:
+  InvestmentItem(QTreeWidget *view) : QTreeWidgetItem(view) {}
+  virtual bool operator<(const QTreeWidgetItem &other) const;
+};
+
+bool InvestmentItem::operator<(const QTreeWidgetItem &other) const
+{
+  const int sortColumn = treeWidget()->sortColumn();
+  if (sortColumn > eInvestmentSymbolColumn) {
+    // these columns have a MyMoneyMoney value in the Qt::UserRole role
+    const MyMoneyMoney &money = data(sortColumn, Qt::UserRole).value<MyMoneyMoney>();
+    const MyMoneyMoney &otherMoney = other.data(sortColumn, Qt::UserRole).value<MyMoneyMoney>();
+    return money < otherMoney;
+  }
+  return QTreeWidgetItem::operator<(other);
+}
+
 class KInvestmentView::Private
 {
 public:
@@ -97,7 +119,7 @@ KInvestmentView::KInvestmentView(QWidget *parent) :
   for (int i = 0; i < MaxViewTabs; ++i)
     d->m_needReload[i] = false;
 
-  connect(m_tab, SIGNAL(currentChanged(QWidget*)), this, SLOT(slotTabCurrentChanged(QWidget*)));
+  connect(m_tab, SIGNAL(currentChanged(int)), this, SLOT(slotTabCurrentChanged(int)));
 
   connect(m_investmentsList, SIGNAL(customContextMenuRequested(QPoint)),
           this, SLOT(slotInvestmentContextMenu(QPoint)));
@@ -175,8 +197,7 @@ void KInvestmentView::slotInvestmentSelectionChanged()
       MyMoneyAccount account = MyMoneyFile::instance()->account(item->data(0, Qt::UserRole).value<MyMoneyAccount>().id());
       kmymoney->slotSelectInvestment(account);
 
-    } catch (MyMoneyException *e) {
-      delete e;
+    } catch (const MyMoneyException &) {
     }
   }
 }
@@ -196,12 +217,12 @@ void KInvestmentView::slotLoadView(void)
   d->m_needReload[EquitiesTab] = true;
   d->m_needReload[SecuritiesTab] = true;
   if (isVisible())
-    slotTabCurrentChanged(m_tab->currentWidget());
+    slotTabCurrentChanged(m_tab->currentIndex());
 }
 
-void KInvestmentView::slotTabCurrentChanged(QWidget* _tab)
+void KInvestmentView::slotTabCurrentChanged(int index)
 {
-  InvestmentsViewTab tab = static_cast<InvestmentsViewTab>(m_tab->indexOf(_tab));
+  InvestmentsViewTab tab = static_cast<InvestmentsViewTab>(index);
 
   loadView(tab);
 }
@@ -215,8 +236,7 @@ void KInvestmentView::loadAccounts(void)
   if (!d->m_account.id().isEmpty()) {
     try {
       d->m_account = file->account(d->m_account.id());
-    } catch (MyMoneyException *e) {
-      delete e;
+    } catch (const MyMoneyException &) {
       d->m_account = MyMoneyAccount();
     }
   }
@@ -234,7 +254,7 @@ void KInvestmentView::loadAccounts(void)
     for (QModelIndexList::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it) {
       if (!it->parent().isValid())
         continue; // skip the top level accounts
-      QVariant accountId = d->m_filterProxyModel->data(*it, AccountsModel::AccountIdRole);
+      QVariant accountId = (*it).data(AccountsModel::AccountIdRole);
       if (accountId.isValid()) {
         MyMoneyAccount a = file->account(accountId.toString());
         if (a.value("PreferredAccount") == "Yes") {
@@ -251,9 +271,8 @@ void KInvestmentView::loadAccounts(void)
     m_accountComboBox->setSelected(d->m_account.id());
     try {
       d->m_precision = MyMoneyMoney::denomToPrec(d->m_account.fraction());
-    } catch (MyMoneyException *e) {
+    } catch (const MyMoneyException &) {
       qDebug("Security %s for account %s not found", qPrintable(d->m_account.currencyId()), qPrintable(d->m_account.name()));
-      delete e;
       d->m_precision = 2;
     }
   }
@@ -300,9 +319,8 @@ bool KInvestmentView::slotSelectAccount(const QString& id, const QString& transa
           rc = false;
         }
 
-      } catch (MyMoneyException* e) {
+      } catch (const MyMoneyException &) {
         qDebug("Unable to retrieve account %s", qPrintable(id));
-        delete e;
         rc = false;
       }
     } else {
@@ -369,10 +387,9 @@ void KInvestmentView::loadInvestmentTab(void)
       if (!acc.isClosed() || showClosedAccounts)
         loadInvestmentItem(acc);
     }
-  } catch (MyMoneyException* e) {
+  } catch (const MyMoneyException &) {
     qDebug("KInvestmentView::loadView() - selected account does not exist anymore");
     d->m_account = MyMoneyAccount();
-    delete e;
   }
 
   // and tell everyone what's selected
@@ -381,7 +398,7 @@ void KInvestmentView::loadInvestmentTab(void)
 
 void KInvestmentView::loadInvestmentItem(const MyMoneyAccount& account)
 {
-  QTreeWidgetItem* item = new QTreeWidgetItem(m_investmentsList);
+  QTreeWidgetItem* item = new InvestmentItem(m_investmentsList);
   MyMoneySecurity security;
   MyMoneyFile* file = MyMoneyFile::instance();
 
@@ -398,9 +415,12 @@ void KInvestmentView::loadInvestmentItem(const MyMoneyAccount& account)
   item->setText(eInvestmentSymbolColumn, security.tradingSymbol());
 
   //column 2 is the net value (price * quantity owned)
-  MyMoneyPrice price = file->price(account.currencyId(), tradingCurrency.id());
+  const MyMoneyPrice &price = file->price(account.currencyId(), tradingCurrency.id());
+  const MyMoneyMoney &balance = file->balance(account.id());
   if (price.isValid()) {
-    item->setText(eValueColumn, (file->balance(account.id()) * price.rate(tradingCurrency.id())).formatMoney(tradingCurrency.tradingSymbol(), prec));
+    const MyMoneyMoney &value = balance * price.rate(tradingCurrency.id());
+    item->setText(eValueColumn, value.formatMoney(tradingCurrency.tradingSymbol(), prec));
+    item->setData(eValueColumn, Qt::UserRole, QVariant::fromValue(value));
   } else {
     item->setText(eValueColumn, "---");
   }
@@ -408,8 +428,10 @@ void KInvestmentView::loadInvestmentItem(const MyMoneyAccount& account)
 
   //column 3 (COLUMN_QUANTITY_INDEX) is the quantity of shares owned
   prec = MyMoneyMoney::denomToPrec(security.smallestAccountFraction());
-  item->setText(eQuantityColumn, file->balance(account.id()).formatMoney("", prec));
+
+  item->setText(eQuantityColumn, balance.formatMoney("", prec));
   item->setTextAlignment(eQuantityColumn, Qt::AlignRight | Qt::AlignVCenter);
+  item->setData(eQuantityColumn, Qt::UserRole, QVariant::fromValue(balance));
 
   //column 4 is the current price
   // Get the price precision from the configuration
@@ -418,6 +440,7 @@ void KInvestmentView::loadInvestmentItem(const MyMoneyAccount& account)
   // prec = MyMoneyMoney::denomToPrec(m_tradingCurrency.smallestAccountFraction());
   if (price.isValid()) {
     item->setText(ePriceColumn, price.rate(tradingCurrency.id()).formatMoney(tradingCurrency.tradingSymbol(), prec));
+    item->setData(ePriceColumn, Qt::UserRole, QVariant::fromValue(price.rate(tradingCurrency.id())));
   } else {
     item->setText(ePriceColumn, "---");
   }
@@ -437,7 +460,7 @@ void KInvestmentView::showEvent(QShowEvent* event)
     emit accountSelected(d->m_account);
   }*/
 
-  slotTabCurrentChanged(m_tab->currentWidget());
+  slotTabCurrentChanged(m_tab->currentIndex());
 
   // don't forget base class implementation
   QWidget::showEvent(event);
@@ -521,9 +544,8 @@ void KInvestmentView::slotEditSecurity(void)
           security = MyMoneyFile::instance()->security(item->text(eIdColumn).toLatin1());
           loadSecurityItem(item, security);
         }
-      } catch (MyMoneyException* e) {
-        KMessageBox::error(this, i18n("Failed to edit security: %1", e->what()));
-        delete e;
+      } catch (const MyMoneyException &e) {
+        KMessageBox::error(this, i18n("Failed to edit security: %1", e.what()));
       }
     }
     delete dlg;
@@ -552,11 +574,8 @@ void KInvestmentView::slotDeleteSecurity(void)
         else
           MyMoneyFile::instance()->removeSecurity(security);
         ft.commit();
-      } catch (MyMoneyException *e) {
-        delete e;
+      } catch (const MyMoneyException &) {
       }
     }
   }
 }
-
-#include "kinvestmentview.moc"
